"""
A test that requires no indexes
"""

from drivers.alr import run_alr
# from drivers.asserts import assert_eq, assert_match


run_alr()


print("SUCCESS")
